==> CoCo_0.1.6.5.tar.gz: CoCo/CoCoCore/R/ok.coco.R <==
"ok.coco" <-
function (result, no.warnings = NULL) 
{
    if (result$ifail != .no.ifail) 
        cat("\n")
    if (result[[2]] == .ended.coco) 
        warning("This CoCo-object ended")
    if (ifelse(is.logical(no.warnings), !no.warnings,
               !(is.element(result[[2]], no.warnings)))) {
        if (result$ifail == 1) 
            warning("This CoCo-object not started")
        if (result$ifail == 2) 
            warning("This CoCo-object ended")
        if (result$ifail == 3) 
            warning("Command not implemented")
        if (result$ifail == 11) 
            warning("No Data read")
        if (result$ifail == 12) 
            warning("No Specification read")
        if (result$ifail == 13) 
            warning("No Observations read")
        if (result$ifail == 15) 
            warning("Factor-set not subset of missing excluded")
        if (result$ifail == 19) 
            warning("Not a generating class")
        if (result$ifail == 20) 
            warning("No such model")
        if (result$ifail == 21) 
            warning("No model with that number")
        if (result$ifail == 22) 
            warning("No CURRENT model")
        if (result$ifail == 23) 
            warning("No BASE model")
        if (result$ifail == 24) 
            warning("No LAST model")
        if (result$ifail == 25) 
            warning("No CURRENT or BASE model")
        if (result$ifail == 26) 
            warning("No CURRENT and BASE model")
        if (result$ifail == 27) 
            warning("CURRENT not submodel of BASE")
        if (result$ifail == 28) 
            warning("CURRENT and BASE model have not same causal structure")
        if (result$ifail == 29) 
            warning("Model is not pure discrete")
        if (result$ifail == 30) 
            warning("Out of space")
        if (result$ifail == 31) 
            warning("Out of space: N-array")
        if (result$ifail == 32) 
            warning("Out of space: P-array")
        if (result$ifail == 33) 
            warning("Out of space: Q-array")
        if (result$ifail == 34) 
            warning("Out of space: R-array")
        if (result$ifail == 35) 
            warning("Out of space: S-array")
        if (result$ifail == 36) 
            warning("Out of space: SS-array")
        if (result$ifail == 37) 
            warning("Out of space: T-array")
        if (result$ifail == 41) 
            warning("Out of space: CURRENT")
        if (result$ifail == 42) 
            warning("Out of space: BASE")
        if (result$ifail == 43) 
            warning("Out of space: Marginals")
        if (result$ifail == 44) 
            warning("Out of space: Adjusted DF")
        if (result$ifail == 45) 
            warning("Out of space: IPS")
        if (result$ifail == 46) 
            warning("Out of space: EM")
        if (result$ifail == 46) 
            warning("Out of space: Collaps")
        if (result$ifail == 50) 
            warning("No such file")
        if (result$ifail == 51) 
            warning("Filename not set")
        if (result$ifail == 52) 
            warning("No parser table: Unable to decide on context of actions")
        if (result$ifail == 56) 
            warning("Unable to write in temporary directory")
        if (result$ifail == 57) 
            warning("No COCO_TMP environment variable")
        if (result$ifail == 58) 
            warning("No COCO_LIB environment variable")
        if (result$ifail == 59) 
            warning("(No COCO_HOME environment variable)")
        if (result$ifail == 60) 
            warning("Invalid vector in argument")
        if (result$ifail == 70) 
            warning("Vector in argument too short")
        if (result$ifail == 71) 
            warning("To few factors: Two expected")
        if (result$ifail == 72) 
            warning("Not implemented for EM")
        if (result$ifail == 73) 
            warning("No such function/Not implemented")
        if (result$ifail == 80) 
            warning("No such factor")
        if (result$ifail == 81) 
            warning("No cutpoints for this factor")
        if (result$ifail != .no.ifail) 
            warning("Some Error")
    }
    return((result$ifail == .no.ifail) && (result[[2]] != .ended.coco))
}

==> CoCo_0.1.7.4.tar.gz: CoCo/CoCoCore/R/ok.coco.R <==
"ok.coco" <-
function (result, no.warnings = NULL) 
{
    if (result$ifail != CoCoCore::.noIfail()) 
        cat("\n")
    if (result[[2]] == CoCoCore::.endedCoCo()) 
        warning("This CoCo-object ended")
    if (ifelse(is.logical(no.warnings), !no.warnings,
               !(is.element(result[[2]], no.warnings)))) {
        if (result$ifail == 1) 
            warning("This CoCo-object not started")
        if (result$ifail == 2) 
            warning("This CoCo-object ended")
        if (result$ifail == 3) 
            warning("Command not implemented")
        if (result$ifail == 11) 
            warning("No Data read")
        if (result$ifail == 12) 
            warning("No Specification read")
        if (result$ifail == 13) 
            warning("No Observations read")
        if (result$ifail == 15) 
            warning("Factor-set not subset of missing excluded")
        if (result$ifail == 19) 
            warning("Not a generating class")
        if (result$ifail == 20) 
            warning("No such model")
        if (result$ifail == 21) 
            warning("No model with that number")
        if (result$ifail == 22) 
            warning("No CURRENT model")
        if (result$ifail == 23) 
            warning("No BASE model")
        if (result$ifail == 24) 
            warning("No LAST model")
        if (result$ifail == 25) 
            warning("No CURRENT or BASE model")
        if (result$ifail == 26) 
            warning("No CURRENT and BASE model")
        if (result$ifail == 27) 
            warning("CURRENT not submodel of BASE")
        if (result$ifail == 28) 
            warning("CURRENT and BASE model have not same causal structure")
        if (result$ifail == 29) 
            warning("Model is not pure discrete")
        if (result$ifail == 30) 
            warning("Out of space")
        if (result$ifail == 31) 
            warning("Out of space: N-array")
        if (result$ifail == 32) 
            warning("Out of space: P-array")
        if (result$ifail == 33) 
            warning("Out of space: Q-array")
        if (result$ifail == 34) 
            warning("Out of space: R-array")
        if (result$ifail == 35) 
            warning("Out of space: S-array")
        if (result$ifail == 36) 
            warning("Out of space: SS-array")
        if (result$ifail == 37) 
            warning("Out of space: T-array")
        if (result$ifail == 41) 
            warning("Out of space: CURRENT")
        if (result$ifail == 42) 
            warning("Out of space: BASE")
        if (result$ifail == 43) 
            warning("Out of space: Marginals")
        if (result$ifail == 44) 
            warning("Out of space: Adjusted DF")
        if (result$ifail == 45) 
            warning("Out of space: IPS")
        if (result$ifail == 46) 
            warning("Out of space: EM")
        if (result$ifail == 46) 
            warning("Out of space: Collaps")
        if (result$ifail == 50) 
            warning("No such file")
        if (result$ifail == 51) 
            warning("Filename not set")
        if (result$ifail == 52) 
            warning("No parser table: Unable to decide on context of actions")
        if (result$ifail == 56) 
            warning("Unable to write in temporary directory")
        if (result$ifail == 57) 
            warning("No COCO_TMP environment variable")
        if (result$ifail == 58) 
            warning("No COCO_LIB environment variable")
        if (result$ifail == 59) 
            warning("(No COCO_HOME environment variable)")
        if (result$ifail == 60) 
            warning("Invalid vector in argument")
        if (result$ifail == 70) 
            warning("Vector in argument too short")
        if (result$ifail == 71) 
            warning("To few factors: Two expected")
        if (result$ifail == 72) 
            warning("Not implemented for EM")
        if (result$ifail == 73) 
            warning("No such function/Not implemented")
        if (result$ifail == 80) 
            warning("No such factor")
        if (result$ifail == 81) 
            warning("No cutpoints for this factor")
        if (result$ifail != CoCoCore::.noIfail()) 
            warning("Some Error")
    }
    return((result$ifail == CoCoCore::.noIfail()) && (result[[2]] != CoCoCore::.endedCoCo()))
}
